@@ -14,13 +14,30 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: ox_magnum.cc,v 1.1 2004/02/15 11:32:52 dheck Exp $
  */
-#include "oxyd_internal.hh"
 
-using namespace enigma::world;
+#if defined(PLAIN_SPEC_ONLY)
+// This is used from lib-src/oxydlib/EnigmaNames.cpp.
+//
+// defining PLAIN_SPEC_ONLY only shows xxx_floor_map, xxx_stone_map and xxx_item_map
+// Note:  the xxx_item_map changes it's type (ItemID -> const char *)
+
+#define ITEMSPEC(i) #i
+#define ITEMMAPTYPE const char *
+
+#else
+// Standard enigma section :
+
+#define ITEMSPEC(i) i
+#define ITEMMAPTYPE world::ItemID
+
+#include "oxyd_internal.hh"
+using namespace world;
+
+#endif // PLAIN_SPEC_ONLY
+// only tables following!
 
 const char *oxyd::oxydmag_floor_map[256] = {
     "fl-abyss",                 // OxydMagnum floor 0x00
@@ -28,7 +45,7 @@ const char *oxyd::oxydmag_floor_map[256] = {
     "fl-metal",                 // OxydMagnum floor 0x02 (This should be "fl-stwood" for #112)
     "fl-metal3",                // OxydMagnum floor 0x03
     "fl-metal4",                // OxydMagnum floor 0x04
-    0,                          // OxydMagnum floor 0x05 (common was 'fl-metal')
+    0,                          // OxydMagnum floor 0x05 (common was 'fl-metal')(level 121 ?)
     "fl-metal5",                // OxydMagnum floor 0x06
     "fl-normal",                // OxydMagnum floor 0x07 (common was 'fl-metal')
     "fl-tigris",                // OxydMagnum floor 0x08 (common was 'fl-rough')
@@ -86,10 +103,10 @@ const char *oxyd::oxydmag_floor_map[256] = {
     "fl-rock",                  // OxydMagnum floor 0x3c
     UNUSED,                     // OxydMagnum floor 0x3d
     UNUSED,                     // OxydMagnum floor 0x3e
-    0,                          // OxydMagnum floor 0x3f
+    0,                          // OxydMagnum floor 0x3f (Level 121 ?)(in normal Oxyd Magnum Levels unused!)
     "fl-stwood1",               // OxydMagnum floor 0x40
     "fl-wood",                  // OxydMagnum floor 0x41
-    0,                          // OxydMagnum floor 0x42
+    "fl-wood1",                 // OxydMagnum floor 0x42
     UNUSED,                     // OxydMagnum floor 0x43
     UNUSED,                     // OxydMagnum floor 0x44
     UNUSED,                     // OxydMagnum floor 0x45
@@ -113,7 +130,7 @@ const char *oxyd::oxydmag_floor_map[256] = {
     UNUSED,                     // OxydMagnum floor 0x57
     "fl-darkgray",              // OxydMagnum floor 0x58
     "fl-leaves",                // OxydMagnum floor 0x59
-    0,                          // OxydMagnum floor 0x5a
+    "fl-normal",                // OxydMagnum floor 0x5a (Only Oxyd Magnum Gold #119,120)
     "fl-plank",                 // OxydMagnum floor 0x5b
     // codes >= 0x5c are unused
 };
@@ -138,8 +155,8 @@ const char *oxyd::oxydmag_stone_map[256] = {
     UNUSED,                     // OxydMagnum stone 0x1e
     "st-brick",                 // OxydMagnum stone 0x1f
     "st-rock1",                 // OxydMagnum stone 0x20
-    0,                          // OxydMagnum stone 0x21
-    0,                          // OxydMagnum stone 0x22 (common was 'st-glass')
+    "st-rock1",                 // OxydMagnum stone 0x21 (Level 121 ?)(Oxyd Magnum Gold)
+    "st-rock1",                 // OxydMagnum stone 0x22 (common was 'st-glass')(Level 73 only)(looks like st-rock1)(looks like 0x20, but not like 0x87)
     "st-woven",                 // OxydMagnum stone 0x23
     "st-marble",                // OxydMagnum stone 0x24
     "st-glass1",                // OxydMagnum stone 0x25
@@ -150,13 +167,13 @@ const char *oxyd::oxydmag_stone_map[256] = {
     "st-plain_move",            // OxydMagnum stone 0x2a
     "st-wood",                  // OxydMagnum stone 0x2b
     "st-switch",                // OxydMagnum stone 0x2c
-    "st-floppy",                // OxydMagnum stone 0x2d
+    "st-floppy",                // OxydMagnum stone 0x2d (in normal Oxyd Magnum Levels unused!)
     UNUSED,                     // OxydMagnum stone 0x2e
-    "st-fourswitch",            // OxydMagnum stone 0x2f
+    "st-fourswitch",            // OxydMagnum stone 0x2f (Level 89 and 92)
     "st-key",                   // OxydMagnum stone 0x30
     "st-floppy",                // OxydMagnum stone 0x31
     "st-knight",                // OxydMagnum stone 0x32
-    0,                          // OxydMagnum stone 0x33
+    "st-fourswitch",            // OxydMagnum stone 0x33 (Level 51 and 100)
     "st-death",                 // OxydMagnum stone 0x34
     "st-death_invisible",       // OxydMagnum stone 0x35
     "st-oneway_black-w",        // OxydMagnum stone 0x36
@@ -168,8 +185,8 @@ const char *oxyd::oxydmag_stone_map[256] = {
     "st-oneway_white-n",        // OxydMagnum stone 0x3c
     "st-oneway_white-s",        // OxydMagnum stone 0x3d
     UNUSED,                     // OxydMagnum stone 0x3e
-    0,                          // OxydMagnum stone 0x3f
-    0,                          // OxydMagnum stone 0x40
+    UNUSED,                     // OxydMagnum stone 0x3f
+    UNUSED,                     // OxydMagnum stone 0x40
     UNUSED,                     // OxydMagnum stone 0x41
     "st-actorimpulse",          // OxydMagnum stone 0x42
     "st-actorimpulse_invisible", // OxydMagnum stone 0x43
@@ -203,7 +220,7 @@ const char *oxyd::oxydmag_stone_map[256] = {
     "st-puzzle2-w",             // Oxyd1 stone 0x5f
     "st-puzzle2-e",             // Oxyd1 stone 0x60
     "st-puzzle2-nesw",          // Oxyd1 stone 0x61
-    "st-rock2_hole",            // OxydMagnum stone 0x62
+    "st-metal_hole",            // OxydMagnum stone 0x62  (st-explosive: like st-metal, but explodes when touched ...)
     "st-plain_break",           // OxydMagnum stone 0x63
     "st-fakeoxyda",             // OxydMagnum stone 0x64
     UNUSED,                     // OxydMagnum stone 0x65
@@ -222,12 +239,12 @@ const char *oxyd::oxydmag_stone_map[256] = {
     "st-mail-s",                // OxydMagnum stone 0x72
     "st-door-h",                // OxydMagnum stone 0x73
     "st-door-v",                // OxydMagnum stone 0x74
-    "st-rock2",                 // OxydMagnum stone 0x75 (common was 'st-rock2')
+    "st-metal",                 // OxydMagnum stone 0x75
     "st-invisible",             // OxydMagnum stone 0x76
     UNUSED,                     // OxydMagnum stone 0x77
-    "st-door-h-open",           // OxydMagnum stone 0x78
+    "st-door-v-open",           // OxydMagnum stone 0x78 (st-door-h-open was wrong, look at level #32)
     UNUSED,                     // OxydMagnum stone 0x79
-    "st-door-v-open",           // OxydMagnum stone 0x7a
+    "st-timeswitch",            // OxydMagnum stone 0x7a (Level 66, this is a solid stone)
     UNUSED,                     // OxydMagnum stone 0x7b
     UNUSED,                     // OxydMagnum stone 0x7c
     UNUSED,                     // OxydMagnum stone 0x7d
@@ -239,26 +256,26 @@ const char *oxyd::oxydmag_stone_map[256] = {
     UNUSED,                     // OxydMagnum stone 0x83
     UNUSED,                     // OxydMagnum stone 0x84
     UNUSED,                     // OxydMagnum stone 0x85
-    "st-rock3_hole",                          // OxydMagnum stone 0x86
-    "st-rock1",                 // OxydMagnum stone 0x87
-    0,                          // OxydMagnum stone 0x88
-    0,                          // OxydMagnum stone 0x89
+    "st-rock3_hole",            // OxydMagnum stone 0x86
+    "st-rock4",                 // OxydMagnum stone 0x87 (was st-rock1, but the pic has straight edges and surfaces)
+    0,                          // OxydMagnum stone 0x88 (Level 121 ?)(in normal Oxyd Magnum Levels unused!)
+    0,                          // OxydMagnum stone 0x89 (Level 121 ?)(in normal Oxyd Magnum Levels unused!)
     "st-stone1",                // OxydMagnum stone 0x8a
     "st-rock6",                 // OxydMagnum stone 0x8b
     "st-white1",                // OxydMagnum stone 0x8c
     "st-black1",                // OxydMagnum stone 0x8d
     "st-yinyang2",              // OxydMagnum stone 0x8e
     UNUSED,                     // OxydMagnum stone 0x8f
-    0,                          // OxydMagnum stone 0x90
+    "st-redrock",               // OxydMagnum stone 0x90 (Level 89 only)
     UNUSED,                     // OxydMagnum stone 0x91
-    0,                          // OxydMagnum stone 0x92
+    "st-fourswitch",            // OxydMagnum stone 0x92 (Level 51 only)
     "st-yinyang1",              // OxydMagnum stone 0x93
     "st-break_acwhite",         // OxydMagnum stone 0x94
     "st-break_acblack",         // OxydMagnum stone 0x95
     "st-chargeplus",            // OxydMagnum stone 0x96
     "st-chargeminus",           // OxydMagnum stone 0x97
     "st-chargezero",            // OxydMagnum stone 0x98
-    0,                          // OxydMagnum stone 0x99 (common was 'st-blocker')
+    0,                          // OxydMagnum stone 0x99 (common was 'st-blocker')(Level 121 ?)(in normal Oxyd Magnum Levels unused!)
     "st-turnstile",             // OxydMagnum stone 0x9a
     "st-turnstile-n",           // OxydMagnum stone 0x9b
     "st-turnstile-s",           // OxydMagnum stone 0x9c
@@ -272,116 +289,116 @@ const char *oxyd::oxydmag_stone_map[256] = {
     "st-stoneimpulse-hollow",   // OxydMagnum stone 0xa4
     UNUSED,                     // OxydMagnum stone 0xa5
     UNUSED,                     // OxydMagnum stone 0xa6
-    0,                          // OxydMagnum stone 0xa7
+    "st-lightpassenger",        // OxydMagnum stone 0xa7
     UNUSED,                     // OxydMagnum stone 0xa8
-    0,                          // OxydMagnum stone 0xa9
+    UNUSED,                     // OxydMagnum stone 0xa9
     // codes >= 0xaa are unused
 };
 
-world::ItemID oxyd::oxydmag_item_map[256] = {
-    it_none,                    // OxydMagnum item 0x00
-    it_extralife,               // OxydMagnum item 0x01
-    it_EXTERNAL,                // OxydMagnum item 0x02 document 1
-    it_EXTERNAL,                // OxydMagnum item 0x03 document 2
-    it_hammer,                  // OxydMagnum item 0x04
-    it_coffee,                  // OxydMagnum item 0x05
-    it_cherry,                  // OxydMagnum item 0x06
-    it_umbrella,                // OxydMagnum item 0x07
-    it_glasses,                 // OxydMagnum item 0x08
-    it_glasses_broken,          // OxydMagnum item 0x09
-    it_dynamite,                // OxydMagnum item 0x0a
-    it_blackbomb,               // OxydMagnum item 0x0b
-    it_whitebomb,               // OxydMagnum item 0x0c
-    it_crack0,                  // OxydMagnum item 0x0d
-    it_crack1,                  // OxydMagnum item 0x0e
-    it_crack2,                  // OxydMagnum item 0x0f
-    it_crack3,                  // OxydMagnum item 0x10
-    it_coin1,                   // OxydMagnum item 0x11
-    it_coin2,                   // OxydMagnum item 0x12
-    it_coin4,                   // OxydMagnum item 0x13
-    it_key_a,                   // OxydMagnum item 0x14
-    it_key_b,                   // OxydMagnum item 0x15
-    it_key_c,                   // OxydMagnum item 0x16
-    it_floppy,                  // OxydMagnum item 0x17
-    it_sword,                   // OxydMagnum item 0x18
-    it_flagwhite,               // OxydMagnum item 0x19
-    it_flagblack,               // OxydMagnum item 0x1a
-    it_ring,                    // OxydMagnum item 0x1b
-    it_pipe_wn,                 // OxydMagnum item 0x1c
-    it_pipe_sw,                 // OxydMagnum item 0x1d
-    it_pipe_ne,                 // OxydMagnum item 0x1e
-    it_pipe_es,                 // OxydMagnum item 0x1f
-    it_pipe_v,                  // OxydMagnum item 0x20
-    it_pipe_h,                  // OxydMagnum item 0x21
-    it_spade,                   // OxydMagnum item 0x22
-    it_UNUSED,                  // OxydMagnum item 0x23
-    it_pin,                     // OxydMagnum item 0x24
-    it_seed,                    // OxydMagnum item 0x25
-    it_spring2,                 // OxydMagnum item 0x26
-    it_spring1,                 // OxydMagnum item 0x27
-    it_bag,                     // OxydMagnum item 0x28
-    it_magnet_off,              // OxydMagnum item 0x29
-    it_inversesensor,           // OxydMagnum item 0x2a
-    it_sensor,                  // OxydMagnum item 0x2b
-    it_shogun_s,                // OxydMagnum item 0x2c
-    it_vortex_open,             // OxydMagnum item 0x2d
-    it_vortex_closed,           // OxydMagnum item 0x2e
-    it_wormhole_on,             // OxydMagnum item 0x2f
-    it_hill,                    // OxydMagnum item 0x30
-    it_tinyhill,                // OxydMagnum item 0x31
-    it_hollow,                  // OxydMagnum item 0x32
-    it_tinyhollow,              // OxydMagnum item 0x33
-    it_vstrip,                  // OxydMagnum item 0x34
-    it_hstrip,                  // OxydMagnum item 0x35
-    it_springboard,           // OxydMagnum item 0x36
-    it_MISSING,                          // OxydMagnum item 0x37
-    it_bridge_oxyd,             // OxydMagnum item 0x38
-    it_UNUSED,                     // OxydMagnum item 0x39
-    it_UNUSED,                     // OxydMagnum item 0x3a
-    it_UNUSED,                     // OxydMagnum item 0x3b
-    it_UNUSED,                     // OxydMagnum item 0x3c
-    it_UNUSED,                     // OxydMagnum item 0x3d
-    it_UNUSED,                     // OxydMagnum item 0x3e
-    it_UNUSED,                     // OxydMagnum item 0x3f
-    it_UNUSED,                     // OxydMagnum item 0x40
-    it_UNUSED,                     // OxydMagnum item 0x41
-    it_UNUSED,                     // OxydMagnum item 0x42
-    it_UNUSED,                     // OxydMagnum item 0x43
-    it_UNUSED,                     // OxydMagnum item 0x44
-    it_UNUSED,                     // OxydMagnum item 0x45
-    it_UNUSED,                     // OxydMagnum item 0x46
-    it_UNUSED,                     // OxydMagnum item 0x47
-    it_UNUSED,                     // OxydMagnum item 0x48
-    it_UNUSED,                     // OxydMagnum item 0x49
-    it_UNUSED,                     // OxydMagnum item 0x4a
-    it_UNUSED,                     // OxydMagnum item 0x4b
-    it_springboard,           // OxydMagnum item 0x4c
-    it_UNUSED,                     // OxydMagnum item 0x4d
-    it_UNUSED,                     // OxydMagnum item 0x4e
-    it_UNUSED,                     // OxydMagnum item 0x4f
-    it_UNUSED,                     // OxydMagnum item 0x50
-    it_UNUSED,                     // OxydMagnum item 0x51
-    it_UNUSED,                     // OxydMagnum item 0x52
-    it_UNUSED,                     // OxydMagnum item 0x53
-    it_UNUSED,                     // OxydMagnum item 0x54
-    it_UNUSED,                     // OxydMagnum item 0x55
-    it_UNUSED,                     // OxydMagnum item 0x56
-    it_UNUSED,                     // OxydMagnum item 0x57
-    it_UNUSED,                     // OxydMagnum item 0x58
-    it_UNUSED,                     // OxydMagnum item 0x59
-    it_UNUSED,                     // OxydMagnum item 0x5a
-    it_UNUSED,                     // OxydMagnum item 0x5b
-    it_UNUSED,                     // OxydMagnum item 0x5c
-    it_UNUSED,                     // OxydMagnum item 0x5d
-    it_UNUSED,                     // OxydMagnum item 0x5e
-    it_oxyd5f,                  // OxydMagnum item 0x5f
-    it_drop,                    // OxydMagnum item 0x60 (drunk)
-    it_UNUSED,                     // OxydMagnum item 0x61 (rev. breaking area)
-    it_UNUSED,                     // OxydMagnum item 0x62 (player exchange)
-    it_trigger,                 // OxydMagnum item 0x63
-    it_puller_n,              // OxydMagnum item 0x64
-    it_puller_s,              // OxydMagnum item 0x65
-    it_puller_w,              // OxydMagnum item 0x66
-    it_puller_e,              // OxydMagnum item 0x67
+ITEMMAPTYPE oxyd::oxydmag_item_map[256] = {
+    ITEMSPEC(it_none),          // OxydMagnum item 0x00
+    ITEMSPEC(it_extralife),     // OxydMagnum item 0x01
+    ITEMSPEC(it_EXTERNAL),      // OxydMagnum item 0x02 document 1
+    ITEMSPEC(it_EXTERNAL),      // OxydMagnum item 0x03 document 2
+    ITEMSPEC(it_hammer),        // OxydMagnum item 0x04
+    ITEMSPEC(it_coffee),        // OxydMagnum item 0x05
+    ITEMSPEC(it_cherry),        // OxydMagnum item 0x06
+    ITEMSPEC(it_umbrella),      // OxydMagnum item 0x07
+    ITEMSPEC(it_glasses),       // OxydMagnum item 0x08
+    ITEMSPEC(it_glasses_broken), // OxydMagnum item 0x09
+    ITEMSPEC(it_dynamite),      // OxydMagnum item 0x0a
+    ITEMSPEC(it_blackbomb),     // OxydMagnum item 0x0b
+    ITEMSPEC(it_whitebomb),     // OxydMagnum item 0x0c
+    ITEMSPEC(it_crack0),        // OxydMagnum item 0x0d
+    ITEMSPEC(it_crack1),        // OxydMagnum item 0x0e
+    ITEMSPEC(it_crack2),        // OxydMagnum item 0x0f
+    ITEMSPEC(it_crack3),        // OxydMagnum item 0x10
+    ITEMSPEC(it_coin1),         // OxydMagnum item 0x11
+    ITEMSPEC(it_coin2),         // OxydMagnum item 0x12
+    ITEMSPEC(it_coin4),         // OxydMagnum item 0x13
+    ITEMSPEC(it_key_a),         // OxydMagnum item 0x14
+    ITEMSPEC(it_key_b),         // OxydMagnum item 0x15
+    ITEMSPEC(it_key_c),         // OxydMagnum item 0x16
+    ITEMSPEC(it_floppy),        // OxydMagnum item 0x17
+    ITEMSPEC(it_sword),         // OxydMagnum item 0x18
+    ITEMSPEC(it_flagwhite),     // OxydMagnum item 0x19
+    ITEMSPEC(it_flagblack),     // OxydMagnum item 0x1a
+    ITEMSPEC(it_ring),          // OxydMagnum item 0x1b
+    ITEMSPEC(it_pipe_wn),       // OxydMagnum item 0x1c
+    ITEMSPEC(it_pipe_sw),       // OxydMagnum item 0x1d
+    ITEMSPEC(it_pipe_ne),       // OxydMagnum item 0x1e
+    ITEMSPEC(it_pipe_es),       // OxydMagnum item 0x1f
+    ITEMSPEC(it_pipe_v),        // OxydMagnum item 0x20
+    ITEMSPEC(it_pipe_h),        // OxydMagnum item 0x21
+    ITEMSPEC(it_spade),         // OxydMagnum item 0x22
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x23
+    ITEMSPEC(it_pin),           // OxydMagnum item 0x24
+    ITEMSPEC(it_seed),          // OxydMagnum item 0x25
+    ITEMSPEC(it_spring2),       // OxydMagnum item 0x26
+    ITEMSPEC(it_spring1),       // OxydMagnum item 0x27
+    ITEMSPEC(it_bag),           // OxydMagnum item 0x28
+    ITEMSPEC(it_magnet_off),    // OxydMagnum item 0x29
+    ITEMSPEC(it_inversesensor), // OxydMagnum item 0x2a
+    ITEMSPEC(it_sensor),        // OxydMagnum item 0x2b
+    ITEMSPEC(it_shogun_s),      // OxydMagnum item 0x2c
+    ITEMSPEC(it_vortex_open),   // OxydMagnum item 0x2d
+    ITEMSPEC(it_vortex_closed), // OxydMagnum item 0x2e
+    ITEMSPEC(it_wormhole_on),   // OxydMagnum item 0x2f
+    ITEMSPEC(it_hill),          // OxydMagnum item 0x30
+    ITEMSPEC(it_tinyhill),      // OxydMagnum item 0x31
+    ITEMSPEC(it_hollow),        // OxydMagnum item 0x32
+    ITEMSPEC(it_tinyhollow),    // OxydMagnum item 0x33
+    ITEMSPEC(it_vstrip),        // OxydMagnum item 0x34
+    ITEMSPEC(it_hstrip),        // OxydMagnum item 0x35
+    ITEMSPEC(it_springboard),   // OxydMagnum item 0x36
+    ITEMSPEC(it_MISSING),       // OxydMagnum item 0x37
+    ITEMSPEC(it_bridge_oxyd),   // OxydMagnum item 0x38
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x39
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x3a
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x3b
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x3c
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x3d
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x3e
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x3f
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x40
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x41
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x42
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x43
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x44
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x45
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x46
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x47
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x48
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x49
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x4a
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x4b
+    ITEMSPEC(it_springboard),   // OxydMagnum item 0x4c
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x4d
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x4e
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x4f
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x50
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x51
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x52
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x53
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x54
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x55
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x56
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x57
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x58
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x59
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x5a
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x5b
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x5c
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x5d
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x5e
+    ITEMSPEC(it_oxyd5f),        // OxydMagnum item 0x5f
+    ITEMSPEC(it_drop),          // OxydMagnum item 0x60 (drunk)
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x61 (rev. breaking area)
+    ITEMSPEC(it_UNUSED),        // OxydMagnum item 0x62 (player exchange)
+    ITEMSPEC(it_trigger),       // OxydMagnum item 0x63
+    ITEMSPEC(it_puller_n),      // OxydMagnum item 0x64
+    ITEMSPEC(it_puller_s),      // OxydMagnum item 0x65
+    ITEMSPEC(it_puller_w),      // OxydMagnum item 0x66
+    ITEMSPEC(it_puller_e),      // OxydMagnum item 0x67
     // codes >= 0x68 are unused
 };
